@@ -18,34 +18,8 @@
  * along with Miniature. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <config.h>
-#include <main.h>
 #include <pregame.h>
 
-MMainWindow::~MMainWindow()
-{}
-
-void MMainWindow::appendDebugOutput(const QString &msg)
-{
-    Q_UNUSED(msg);
-    // no impl
-}
-
-void MMainWindow::toggleDebugOutput()
-{
-    // no impl
-}
-
-QDBusAppActivator::QDBusAppActivator(MMainWindow *window)
-: QDBusAbstractAdaptor(window),
-  m_window(window)
-{}
-
-void QDBusAppActivator::top_application()
-{
-    m_window->activateWindow();
-}
-
 int main(int argc, char ** argv)
 {
     // raster backend is faster than native, but not as disruptive as opengl
@@ -53,7 +27,8 @@ int main(int argc, char ** argv)
     QApplication app(argc, argv);
 
     Miniature::MPreGame pre_game;
-    pre_game.onStartScreenRequested();
+    if (!(app.argc() > 1 && app.argv()[1] == QString("--no-ui")))
+        pre_game.onStartScreenRequested();
 
     return app.exec();
 }
